@@ -1,7 +1,17 @@
-SELbank<-function(QB, N)
+SELbank<-function(QB, N, xclude=NULL)
   {
     ###   make random selection of  question bank
     ch = 1:length(QB)
+
+    
+    if(!is.null(xclude) & !identical(xclude, 0) )
+      {
+       ch =  ch[-xclude]
+
+      }
+
+    if(length(ch)<N) N = length(ch)
+    
     ran1 = sample(ch, N )
 
     KBnew = vector(mode='list')
